@@ -135,6 +135,35 @@ format_date_and_time_x		(struct tm	*date_tm,
 				 int		 buffer_size)
 {
 	char *format;
+	struct tm tomorrow_tm, week_tm;
+	
+	/* Calculate a normalized "tomorrow" */
+	tomorrow_tm = *current_tm;
+	if (tomorrow_tm.tm_mday == time_days_in_month (date_tm->tm_year + 1900, date_tm->tm_mon)) {
+		tomorrow_tm.tm_mday = 1;
+		if (tomorrow_tm.tm_mon == 11) {
+			tomorrow_tm.tm_mon = 1;
+			tomorrow_tm.tm_year++;
+		} else {
+			tomorrow_tm.tm_mon++;
+		}
+	} else {		
+		tomorrow_tm.tm_mday++;
+	}
+
+	/* Calculate a normalized "next seven days" */
+	week_tm = *current_tm;
+	if (week_tm.tm_mday + 6 > time_days_in_month (date_tm->tm_year + 1900, date_tm->tm_mon)) {
+		week_tm.tm_mday = (week_tm.tm_mday + 6) % time_days_in_month (date_tm->tm_year + 1900, date_tm->tm_mon);
+		if (week_tm.tm_mon == 11) {
+			week_tm.tm_mon = 1;
+			week_tm.tm_year++;
+		} else {
+			week_tm.tm_mon++;
+		}
+	} else {		
+		week_tm.tm_mday += 6;
+	}
 
 	/* Today */
 	if (date_tm->tm_mday == current_tm->tm_mday &&
@@ -146,72 +175,85 @@ format_date_and_time_x		(struct tm	*date_tm,
 			format = _("Today");
 		} else if (use_24_hour_format) {
 			if (!show_zero_seconds && date_tm->tm_sec == 0)
-				/* strftime format of a weekday, a date and a
-				   time, in 24-hour format, without seconds. */
+				/* strftime format of a time, 
+				   in 24-hour format, without seconds. */
 				format = _("Today %H:%M");
 			else
-				/* strftime format of a weekday, a date and a
-				   time, in 24-hour format. */
+				/* strftime format of a time, 
+				   in 24-hour format. */
 				format = _("Today %H:%M:%S");
 		} else {
 			if (!show_zero_seconds && date_tm->tm_sec == 0)
-				/* strftime format of a weekday, a date and a
-				   time, in 12-hour format, without seconds. */
+				/* strftime format of a time,
+				   in 12-hour format, without seconds. */
 				format = _("Today %l:%M %p");
 			else
-				/* strftime format of a weekday, a date and a
-				   time, in 12-hour format. */
+				/* strftime format of a time, 
+				   in 12-hour format. */
 				format = _("Today %l:%M:%S %p");
 		}
 
 	/* Tomorrow */		
-	} else if (date_tm->tm_year == current_tm->tm_year) {
+	} else if (date_tm->tm_mday == tomorrow_tm.tm_mday &&
+		   date_tm->tm_mon == tomorrow_tm.tm_mon &&
+		   date_tm->tm_year == tomorrow_tm.tm_year) {
 		if (!show_midnight && date_tm->tm_hour == 0
 		    && date_tm->tm_min == 0 && date_tm->tm_sec == 0) {
 			/* strftime format of a weekday and a date. */
-			format = _("%A, %B %e");
+			format = _("Tomorrow");
 		} else if (use_24_hour_format) {
 			if (!show_zero_seconds && date_tm->tm_sec == 0)
-				/* strftime format of a weekday, a date and a
-				   time, in 24-hour format, without seconds. */
-				format = _("%A, %B %e %H:%M");
+				/* strftime format of a time, 
+				   in 24-hour format, without seconds. */
+				format = _("Tomorrow %H:%M");
 			else
-				/* strftime format of a weekday, a date and a
-				   time, in 24-hour format. */
-				format = _("%A, %B %e %H:%M:%S");
+				/* strftime format of a time, 
+				   in 24-hour format. */
+				format = _("Tomorrow %H:%M:%S");
 		} else {
 			if (!show_zero_seconds && date_tm->tm_sec == 0)
-				/* strftime format of a weekday, a date and a
-				   time, in 12-hour format, without seconds. */
-				format = _("%A, %B %e %l:%M %p");
+				/* strftime format of a time,
+				   in 12-hour format, without seconds. */
+				format = _("Tomorrow %l:%M %p");
 			else
-				/* strftime format of a weekday, a date and a
-				   time, in 12-hour format. */
-				format = _("%A, %B %e %l:%M:%S %p");
+				/* strftime format of a time, 
+				   in 12-hour format. */
+				format = _("Tomorrow %l:%M:%S %p");
 		}
 
-	/* Within 7 days */		
-	} else if (date_tm->tm_year == current_tm->tm_year) {
+	/* Within 6 days */		
+	} else if ((date_tm->tm_year >= current_tm->tm_year &&
+		    date_tm->tm_mon >= current_tm->tm_mon &&
+		    date_tm->tm_mday >= current_tm->tm_mday) &&
+
+		   (date_tm->tm_year < week_tm.tm_year ||
+
+		   (date_tm->tm_year == week_tm.tm_year &&
+		    date_tm->tm_mon < week_tm.tm_mon) ||
+
+		   (date_tm->tm_year == week_tm.tm_year &&
+		    date_tm->tm_mon == week_tm.tm_mon &&
+		    date_tm->tm_mday < week_tm.tm_mday))) {
 		if (!show_midnight && date_tm->tm_hour == 0
 		    && date_tm->tm_min == 0 && date_tm->tm_sec == 0) {
-			/* strftime format of a weekday and a date. */
+			/* strftime format of a weekday. */
 			format = _("%A");
 		} else if (use_24_hour_format) {
 			if (!show_zero_seconds && date_tm->tm_sec == 0)
-				/* strftime format of a weekday, a date and a
+				/* strftime format of a weekday and a
 				   time, in 24-hour format, without seconds. */
 				format = _("%A %H:%M");
 			else
-				/* strftime format of a weekday, a date and a
+				/* strftime format of a weekday and a
 				   time, in 24-hour format. */
 				format = _("%A %H:%M:%S");
 		} else {
 			if (!show_zero_seconds && date_tm->tm_sec == 0)
-				/* strftime format of a weekday, a date and a
+				/* strftime format of a weekday and a
 				   time, in 12-hour format, without seconds. */
 				format = _("%A %l:%M %p");
 			else
-				/* strftime format of a weekday, a date and a
+				/* strftime format of a weekday and a
 				   time, in 12-hour format. */
 				format = _("%A %l:%M:%S %p");
 		}
@@ -220,25 +262,27 @@ format_date_and_time_x		(struct tm	*date_tm,
 	} else if (date_tm->tm_year == current_tm->tm_year) {
 		if (!show_midnight && date_tm->tm_hour == 0
 		    && date_tm->tm_min == 0 && date_tm->tm_sec == 0) {
-			/* strftime format of a weekday and a date. */
+			/* strftime format of a weekday and a date
+			   without a year. */
 			format = _("%A, %B %e");
 		} else if (use_24_hour_format) {
 			if (!show_zero_seconds && date_tm->tm_sec == 0)
-				/* strftime format of a weekday, a date and a
-				   time, in 24-hour format, without seconds. */
+				/* strftime format of a weekday, a date 
+				   without a year and a time, 
+				   in 24-hour format, without seconds. */
 				format = _("%A, %B %e %H:%M");
 			else
-				/* strftime format of a weekday, a date and a
-				   time, in 24-hour format. */
+				/* strftime format of a weekday, a date without a year
+				   and a time, in 24-hour format. */
 				format = _("%A, %B %e %H:%M:%S");
 		} else {
 			if (!show_zero_seconds && date_tm->tm_sec == 0)
-				/* strftime format of a weekday, a date and a
-				   time, in 12-hour format, without seconds. */
+				/* strftime format of a weekday, a date without a year 
+				   and a time, in 12-hour format, without seconds. */
 				format = _("%A, %B %e %l:%M %p");
 			else
-				/* strftime format of a weekday, a date and a
-				   time, in 12-hour format. */
+				/* strftime format of a weekday, a date without a year
+				   and a time, in 12-hour format. */
 				format = _("%A, %B %e %l:%M:%S %p");
 		}
 	} else {
@@ -773,35 +817,37 @@ itip_view_init (ItipView *view)
 
 	priv->mode = ITIP_VIEW_MODE_NONE;
 	
+	gtk_box_set_spacing (GTK_BOX (view), 12);
+
 	/* The meeting icon */
 	icon = e_icon_factory_get_image (MEETING_ICON, E_ICON_SIZE_LARGE_TOOLBAR);
-	gtk_misc_set_alignment (GTK_MISC (icon), 0, 0);
+	gtk_misc_set_alignment (GTK_MISC (icon), 0.5, 0);
 	gtk_widget_show (icon);
 
-	gtk_box_pack_start (GTK_BOX (view), icon, FALSE, FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (view), icon, FALSE, FALSE, 0);
 
 	/* The RHS */
-	vbox = gtk_vbox_new (FALSE, 0);
+	vbox = gtk_vbox_new (FALSE, 12);
 	gtk_widget_show (vbox);
-	gtk_box_pack_start (GTK_BOX (view), vbox, FALSE, FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (view), vbox, FALSE, FALSE, 0);
 
 	/* The first section listing the sender */
 	/* FIXME What to do if the send and organizer do not match */
 	priv->sender_label = gtk_label_new (NULL);
 	gtk_misc_set_alignment (GTK_MISC (priv->sender_label), 0, 0.5);
 	gtk_widget_show (priv->sender_label);
-	gtk_box_pack_start (GTK_BOX (vbox), priv->sender_label, FALSE, FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), priv->sender_label, FALSE, FALSE, 0);
 
 	separator = gtk_hseparator_new ();
 	gtk_widget_show (separator);
-	gtk_box_pack_start (GTK_BOX (vbox), separator, FALSE, FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), separator, FALSE, FALSE, 0);
 
 	/* A table with information on the meeting and any extra info/warnings */
-	table = gtk_table_new (6, 2, FALSE);
+	table = gtk_table_new (4, 2, FALSE);
 	gtk_table_set_row_spacings (GTK_TABLE (table), 6);
 	gtk_table_set_col_spacings (GTK_TABLE (table), 6);
 	gtk_widget_show (table);
-	gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
 
 	/* Summary */
 	priv->summary_label = gtk_label_new (NULL);
@@ -851,64 +897,64 @@ itip_view_init (ItipView *view)
 	gtk_table_attach (GTK_TABLE (table), priv->comment_label, 1, 2, 5, 6, GTK_FILL, 0, 0, 0);
 
 	/* Upper Info items */
-	priv->upper_info_box = gtk_vbox_new (FALSE, 0);
+	priv->upper_info_box = gtk_vbox_new (FALSE, 12);
 	gtk_widget_show (priv->upper_info_box);
-	gtk_box_pack_start (GTK_BOX (vbox), priv->upper_info_box, FALSE, FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), priv->upper_info_box, FALSE, FALSE, 0);
 
 	/* Description */
 	priv->description_label = gtk_label_new (NULL);
 	gtk_label_set_line_wrap (GTK_LABEL (priv->description_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (priv->description_label), 0, 0.5);
-//	gtk_box_pack_start (GTK_BOX (vbox), priv->description_label, FALSE, FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), priv->description_label, FALSE, FALSE, 0);
 
 	separator = gtk_hseparator_new ();
 	gtk_widget_show (separator);
-	gtk_box_pack_start (GTK_BOX (vbox), separator, FALSE, FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), separator, FALSE, FALSE, 0);
 
 	/* Lower Info items */
-	priv->lower_info_box = gtk_vbox_new (FALSE, 0);
+	priv->lower_info_box = gtk_vbox_new (FALSE, 12);
 	gtk_widget_show (priv->lower_info_box);
-	gtk_box_pack_start (GTK_BOX (vbox), priv->lower_info_box, FALSE, FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), priv->lower_info_box, FALSE, FALSE, 0);
 
 	/* Selector area */
-	priv->selector_box = gtk_hbox_new (FALSE, 0);
+	priv->selector_box = gtk_hbox_new (FALSE, 12);
 	gtk_widget_show (priv->selector_box);
 	gtk_box_pack_start (GTK_BOX (vbox), priv->selector_box, FALSE, FALSE, 0);
 	
 	/* RSVP area */
-	priv->rsvp_box = gtk_vbox_new (FALSE, 0);
+	priv->rsvp_box = gtk_vbox_new (FALSE, 12);
 	gtk_box_pack_start (GTK_BOX (vbox), priv->rsvp_box, FALSE, FALSE, 0);
 
 	priv->rsvp_check = gtk_check_button_new_with_mnemonic ("Send _reply to sender");
 	gtk_widget_show (priv->rsvp_check);
-	gtk_box_pack_start (GTK_BOX (priv->rsvp_box), priv->rsvp_check, FALSE, FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (priv->rsvp_box), priv->rsvp_check, FALSE, FALSE, 0);
 
 	g_signal_connect (priv->rsvp_check, "toggled", G_CALLBACK (rsvp_toggled_cb), view);
 
-	hbox = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_hbox_new (FALSE, 12);
 	gtk_widget_show (hbox);
-	gtk_box_pack_start (GTK_BOX (priv->rsvp_box), hbox, FALSE, FALSE, 12);
+	gtk_box_pack_start (GTK_BOX (priv->rsvp_box), hbox, FALSE, FALSE, 0);
 
 	label = gtk_label_new (NULL);
 	gtk_widget_show (label);
-	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 12);
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
 	priv->rsvp_comment_header = gtk_label_new (_("Comment:"));
 	gtk_widget_set_sensitive (priv->rsvp_comment_header, FALSE);
 	gtk_widget_show (priv->rsvp_comment_header);
-	gtk_box_pack_start (GTK_BOX (hbox), priv->rsvp_comment_header, FALSE, FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (hbox), priv->rsvp_comment_header, FALSE, FALSE, 0);
 	
 	priv->rsvp_comment_entry = gtk_entry_new ();
 	gtk_widget_set_sensitive (priv->rsvp_comment_entry, FALSE);
 	gtk_widget_show (priv->rsvp_comment_entry);
-	gtk_box_pack_start (GTK_BOX (hbox), priv->rsvp_comment_entry, FALSE, TRUE, 6);
+	gtk_box_pack_start (GTK_BOX (hbox), priv->rsvp_comment_entry, FALSE, TRUE, 0);
 
 	/* The buttons for actions */
 	priv->button_box = gtk_hbutton_box_new ();
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (priv->button_box), GTK_BUTTONBOX_END);
 	gtk_box_set_spacing (GTK_BOX (priv->button_box), 12);
 	gtk_widget_show (priv->button_box);
-	gtk_box_pack_start (GTK_BOX (vbox), priv->button_box, FALSE, FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), priv->button_box, FALSE, FALSE, 0);
 
 	priv->buttons_sensitive = TRUE;
 }
