@@ -41,8 +41,6 @@
 #include <gtk/gtktypeutils.h>
 #include <gtk/gtkwidget.h>
 
-#include <gal/util/e-util.h>
-
 #include <libgnome/gnome-i18n.h>
 
 #include <glade/glade-xml.h>
@@ -54,10 +52,6 @@
 #define GLADE_DIALOG_FILE_NAME EVOLUTION_GLADEDIR "/e-active-connection-dialog.glade"
 
 
-#define PARENT_TYPE GTK_TYPE_OBJECT
-static GtkObjectClass *parent_class = NULL;
-
-
 /* Private part.  */
 
 struct _OfflineProgressListenerServant {
@@ -114,6 +108,7 @@ enum {
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
+G_DEFINE_TYPE (EShellOfflineHandler, e_shell_offline_handler, GTK_TYPE_OBJECT)
 
 /* Forward declarations for the dialog handling.  */
 
@@ -217,8 +212,8 @@ impl_OfflineProgressListener_updateProgress (PortableServer_Servant servant,
 	update_dialog_clist (offline_handler);
 
 	if (priv->num_total_connections == 0 && ! priv->finished) {
-		g_signal_emit (offline_handler, signals[OFFLINE_PROCEDURE_FINISHED], 0, TRUE);
 		priv->finished = TRUE;
+		g_signal_emit (offline_handler, signals[OFFLINE_PROCEDURE_FINISHED], 0, TRUE);
 	}
 }
 
@@ -389,8 +384,8 @@ cancel_offline (EShellOfflineHandler *offline_handler)
 	priv->num_total_connections = 0;
 
 	if (! priv->finished) {
-		g_signal_emit (offline_handler, signals[OFFLINE_PROCEDURE_FINISHED], 0, FALSE);
 		priv->finished = TRUE;
+		g_signal_emit (offline_handler, signals[OFFLINE_PROCEDURE_FINISHED], 0, FALSE);
 	}
 }
 
@@ -516,8 +511,8 @@ finalize_offline (EShellOfflineHandler *offline_handler)
 
 	if (priv->num_total_connections == 0 && ! priv->finished) {
 		/* Nothing else to do, we are all set.  */
-		g_signal_emit (offline_handler, signals[OFFLINE_PROCEDURE_FINISHED], 0, TRUE);
 		priv->finished = TRUE;
+		g_signal_emit (offline_handler, signals[OFFLINE_PROCEDURE_FINISHED], 0, TRUE);
 	}
 
 	g_object_unref (offline_handler);
@@ -699,7 +694,7 @@ impl_dispose (GObject *object)
 		priv->dialog_gui = NULL;
 	}
 
-	(* G_OBJECT_CLASS (parent_class)->dispose) (object);
+	(* G_OBJECT_CLASS (e_shell_offline_handler_parent_class)->dispose) (object);
 }
 
 static void
@@ -713,14 +708,14 @@ impl_finalize (GObject *object)
 
 	g_free (priv);
 
-	(* G_OBJECT_CLASS (parent_class)->finalize) (object);
+	(* G_OBJECT_CLASS (e_shell_offline_handler_parent_class)->finalize) (object);
 }
 
 
 /* GTK type handling.  */
 
 static void
-class_init (EShellOfflineHandlerClass *klass)
+e_shell_offline_handler_class_init (EShellOfflineHandlerClass *klass)
 {
 	GObjectClass *object_class;
 
@@ -728,8 +723,6 @@ class_init (EShellOfflineHandlerClass *klass)
 	object_class->dispose  = impl_dispose;
 	object_class->finalize = impl_finalize;
 
-	parent_class = g_type_class_ref(gtk_object_get_type ());
-
 	signals[OFFLINE_PROCEDURE_STARTED]
 		= g_signal_new ("offline_procedure_started",
 				G_OBJECT_CLASS_TYPE (object_class),
@@ -752,7 +745,7 @@ class_init (EShellOfflineHandlerClass *klass)
 
 
 static void
-init (EShellOfflineHandler *shell_offline_handler)
+e_shell_offline_handler_init (EShellOfflineHandler *shell_offline_handler)
 {
 	EShellOfflineHandlerPrivate *priv;
 
@@ -853,8 +846,8 @@ e_shell_offline_handler_put_components_offline (EShellOfflineHandler *offline_ha
 	if (! prepare_for_offline (offline_handler)) {
 		/* FIXME: Maybe do something smarter here.  */
 		g_warning ("Couldn't put components off-line");
-		g_signal_emit (offline_handler, signals[OFFLINE_PROCEDURE_FINISHED], 0, FALSE);
 		priv->finished = TRUE;
+		g_signal_emit (offline_handler, signals[OFFLINE_PROCEDURE_FINISHED], 0, FALSE);
 		g_object_unref (offline_handler);
 		return;
 	}
@@ -867,5 +860,3 @@ e_shell_offline_handler_put_components_offline (EShellOfflineHandler *offline_ha
 	g_object_unref (offline_handler);
 }
 
-
-E_MAKE_TYPE (e_shell_offline_handler, "EShellOfflineHandler", EShellOfflineHandler, class_init, init, PARENT_TYPE)
