@@ -281,6 +281,8 @@ subitem_activated_cb (GtkWidget *widget, ESearchBar *esb)
 	esb->subitem_id = subid;
 
 	set_find_now_sensitive (esb, TRUE);
+	
+	gtk_widget_grab_focus (esb->entry);
 }
 
 static char *
@@ -325,6 +327,8 @@ activate_by_subitems (ESearchBar *esb, gint item_id, ESearchBarSubitem *subitems
 		/* Create and add the entry */
 
 		if (esb->entry == NULL) {
+			AtkObject *a11y;
+
 			esb->entry = gtk_entry_new();
 			gtk_widget_set_size_request (esb->entry, 4, -1);
 			g_object_ref (esb->entry);
@@ -335,6 +339,11 @@ activate_by_subitems (ESearchBar *esb, gint item_id, ESearchBarSubitem *subitems
 			gtk_container_add (GTK_CONTAINER (esb->entry_box), esb->entry);
 			gtk_widget_show(esb->entry);
 
+			a11y = gtk_widget_get_accessible (esb->entry);
+			/* To translators: This is the accessibility name of 
+			the search bar's text entry widget */
+			atk_object_set_name (a11y, _("Search Text Entry"));
+
 			esb->subitem_id = -1;
 		}
 
@@ -629,9 +638,14 @@ set_option (ESearchBar *esb, ESearchBarItem *items)
 	if (esb->option) {
 		gtk_widget_destroy (esb->option_menu);
 	} else {
+		AtkObject *a11y;
+
 		esb->option = gtk_option_menu_new ();
 		gtk_widget_show (esb->option);
 		gtk_box_pack_start (GTK_BOX (esb), esb->option, FALSE, FALSE, 0);
+		a11y = gtk_widget_get_accessible (esb->option);
+		atk_object_set_name (a11y, _("Search Type"));
+
 	}
 
 	esb->option_menu = menu = gtk_menu_new ();
